==> openbb_sec-0.1.0a5.tar.gz: openbb_sec-0.1.0a5/openbb_sec/models/cik_map.py <==
"""SEC CIK Mapping Tool."""


from typing import Any, Dict, Optional, Union

from openbb_provider.abstract.data import Data
from openbb_provider.abstract.fetcher import Fetcher
from openbb_provider.standard_models.stock_info import StockInfoQueryParams
from openbb_sec.utils.helpers import symbol_map
from pydantic import Field


class SecCikMapQueryParams(StockInfoQueryParams):
    """SEC Company or Institutions Search query.  This function assists with mapping the CIK number to a company."""


class SecCikMapData(Data):
    """SEC Company Search Data."""

    cik: Optional[Union[str, int]] = Field(
        default=None, description="Central Index Key"
    )


class SecCikMapFetcher(
    Fetcher[
        SecCikMapQueryParams,
        SecCikMapData,
    ]
):
    """Transform the query, extract and transform the data from the SEC."""

    @staticmethod
    def transform_query(params: Dict[str, Any]) -> SecCikMapQueryParams:
        """Transform the query."""
        return SecCikMapQueryParams(**params)

    @staticmethod
    def extract_data(
        query: SecCikMapQueryParams,
        credentials: Optional[Dict[str, str]],
        **kwargs: Any,
    ) -> Dict:
        """Return the raw data from the SEC endpoint."""
        results = {"cik": symbol_map(query.symbol)}
        if results == {}:
            return {"Error": "Symbol not found."}
        return results

    @staticmethod
    def transform_data(data: Dict, **kwargs: Any) -> SecCikMapData:
        """Transform the data to the standard format."""
        return SecCikMapData.model_validate(data)

==> openbb_sec-1.0.0b1.tar.gz: openbb_sec-1.0.0b1/openbb_sec/models/cik_map.py <==
"""SEC CIK Mapping Model."""

from typing import Any, Dict, Optional, Union

from openbb_provider.abstract.data import Data
from openbb_provider.abstract.fetcher import Fetcher
from openbb_provider.standard_models.equity_info import EquityInfoQueryParams
from openbb_sec.utils.helpers import symbol_map
from pydantic import Field


class SecCikMapQueryParams(EquityInfoQueryParams):
    """SEC CIK Mapping Query.

    Source: https://sec.gov/
    """


class SecCikMapData(Data):
    """SEC CIK Mapping Data."""

    cik: Optional[Union[str, int]] = Field(
        default=None, description="Central Index Key"
    )


class SecCikMapFetcher(
    Fetcher[
        SecCikMapQueryParams,
        SecCikMapData,
    ]
):
    """Transform the query, extract and transform the data from the SEC endpoints."""

    @staticmethod
    def transform_query(params: Dict[str, Any]) -> SecCikMapQueryParams:
        """Transform the query."""
        return SecCikMapQueryParams(**params)

    @staticmethod
    def extract_data(
        query: SecCikMapQueryParams,  # pylint: disable=W0613:unused-argument
        credentials: Optional[Dict[str, str]],
        **kwargs: Any,
    ) -> Dict:
        """Return the raw data from the SEC endpoint."""
        results = {"cik": symbol_map(query.symbol)}
        if not results:
            return {"Error": "Symbol not found."}
        return results

    @staticmethod
    def transform_data(
        query: SecCikMapQueryParams, data: Dict, **kwargs: Any
    ) -> SecCikMapData:
        """Transform the data to the standard format."""
        return SecCikMapData.model_validate(data)
